@@ -6,7 +6,7 @@ const proxy = require('proxy-agent')
 module.exports = {
   sdk: aws,
   updateConfig (config, region) {
-    const awsSecurity = { region: region }
+    const awsSecurity = { region }
 
     if (config.profile) {
       aws.config.credentials = new aws.SharedIniFileCredentials({
