@@ -52,7 +52,7 @@ event_sources.json and ${program.eventFile} files as needed.`)
   }
 
   async run (program) {
-    if (!['nodejs14.x', 'nodejs16.x'].includes(program.runtime)) {
+    if (!['nodejs14.x', 'nodejs16.x', 'nodejs18.x'].includes(program.runtime)) {
       console.error(`Runtime [${program.runtime}] is not supported.`)
       process.exit(254)
     }
